@@ -1,5 +1,8 @@
 class TemplateContext:
     def __init__(self, template_path):
+        """
+        :type template_path: str
+        """
         self._template_path = template_path
 
     def build(self, schema):
