@@ -1,57 +1,69 @@
 import requests
 
 import office365.logger
-from office365.runtime.auth.base_token_provider import BaseTokenProvider
+from office365.runtime.auth.authentication_provider import AuthenticationProvider
 from office365.runtime.auth.token_response import TokenResponse
+from office365.runtime.compat import urlparse
 
 
-class ACSTokenProvider(BaseTokenProvider, office365.logger.LoggerContext):
+class ACSTokenProvider(AuthenticationProvider, office365.logger.LoggerContext):
 
-    def __init__(self, url):
+    def __init__(self, url, client_id, client_secret):
         """
         Provider to acquire the access token from a Microsoft Azure Access Control Service (ACS)
 
+        :type client_id: str
+        :type client_secret: str
         :type url: str
         """
-        self.token = TokenResponse()
         self.url = url
         self.redirect_url = None
         self.error = None
         self.SharePointPrincipal = "00000003-0000-0ff1-ce00-000000000000"
+        self._client_id = client_id
+        self._client_secret = client_secret
+        self._cached_token = None
 
-    def is_authenticated(self):
-        return self.token and self.token.is_valid
+    def authenticate_request(self, request):
+        """
+        :type request: office365.runtime.http.request_options.RequestOptions
+        """
+        self.ensure_app_only_access_token()
+        request.set_header('Authorization', self._get_authorization_header())
 
-    def acquire_token(self, **kwargs):
+    def ensure_app_only_access_token(self):
+        if self._cached_token is None:
+            self._cached_token = self.get_app_only_access_token()
+        return self._cached_token and self._cached_token.is_valid
+
+    def get_app_only_access_token(self):
         try:
-            client_id = kwargs.get("client_id")
-            client_secret = kwargs.get("client_secret")
             realm = self._get_realm_from_target_url()
-            try:
-                from urlparse import urlparse  # Python 2.X
-            except ImportError:
-                from urllib.parse import urlparse  # Python 3+
             url_info = urlparse(self.url)
-            self.token = self.get_app_only_access_token(client_id, client_secret, url_info.hostname, realm)
-            return self.token.is_valid
+            return self._get_app_only_access_token(url_info.hostname, realm)
         except requests.exceptions.RequestException as e:
-            self.error = "Error: {}".format(e)
-            return False
+            self.error = e.response.text
+            raise ValueError(e.response.text)
 
-    def get_app_only_access_token(self, client_id, client_secret, target_host, target_realm):
+    def _get_app_only_access_token(self, target_host, target_realm):
         """
 
-        :type client_id: str
-        :type client_secret: str
         :type target_host: str
         :type target_realm: str
         """
         resource = self.get_formatted_principal(self.SharePointPrincipal, target_host, target_realm)
-        principal_id = self.get_formatted_principal(client_id, None, target_realm)
+        principal_id = self.get_formatted_principal(self._client_id, None, target_realm)
         sts_url = self.get_security_token_service_url(target_realm)
-        oauth2_request = self.create_access_token_request(principal_id, client_secret, resource)
+        oauth2_request = {
+            'grant_type': 'client_credentials',
+            'client_id': principal_id,
+            'client_secret': self._client_secret,
+            'scope': resource,
+            'resource': resource
+        }
         response = requests.post(url=sts_url, headers={'Content-Type': 'application/x-www-form-urlencoded'},
                                  data=oauth2_request)
+        response.raise_for_status()
         return TokenResponse.from_json(response.json())
 
     def _get_realm_from_target_url(self):
@@ -77,19 +89,8 @@ class ACSTokenProvider(BaseTokenProvider, office365.logger.LoggerContext):
     def get_security_token_service_url(realm):
         return "https://accounts.accesscontrol.windows.net/{0}/tokens/OAuth/2".format(realm)
 
-    @staticmethod
-    def create_access_token_request(client_id, client_secret, scope):
-        data = {
-            'grant_type': 'client_credentials',
-            'client_id': client_id,
-            'client_secret': client_secret,
-            'scope': scope,
-            'resource': scope
-        }
-        return data
-
-    def get_authorization_header(self):
-        return 'Bearer {0}'.format(self.token.accessToken)
+    def _get_authorization_header(self):
+        return 'Bearer {0}'.format(self._cached_token.accessToken)
 
     def get_last_error(self):
         return self.error
