@@ -1,6 +1,7 @@
 import copy
 
 from office365.runtime.client_value import ClientValue
+from office365.runtime.odata.json_light_format import JsonLightFormat
 from office365.runtime.odata.odata_query_options import QueryOptions
 
 
@@ -99,17 +100,17 @@ class ClientObject(object):
         if isinstance(prop_type, ClientObject) or isinstance(prop_type, ClientValue) and value is not None:
             if isinstance(value, list):
                 [prop_type.set_property(i, v, persist_changes) for i, v in enumerate(value)]
-            else:
+                self._properties[name] = prop_type
+            elif isinstance(value, dict):
                 [prop_type.set_property(k, v, persist_changes) for k, v in value.items()]
-            self._properties[name] = prop_type
+                self._properties[name] = prop_type
+            else:
+                self._properties[name] = value
         else:
             self._properties[name] = value
         return self
 
-    def to_json(self):
-        return dict((k, v) for k, v in self.properties.items() if k in self._changed_properties)
-
-    def ensure_property(self, name, action):
+    def ensure_property(self, name, action=None):
         """
         Ensures if property is loaded
 
@@ -125,17 +126,16 @@ class ClientObject(object):
         :type action: () -> None
         :type names: str or list[str]
         """
+        def _exec_action():
+            if callable(action):
+                action()
+
         names_to_include = [n for n in names if not self.is_property_available(n)]
         if len(names_to_include) > 0:
             qry = self.context.load(self, names_to_include)
-            if callable(action):
-                def _process_query(current_query):
-                    if current_query.id == qry.id:
-                        action()
-
-                self.context.after_execute_query(_process_query)
+            self.context.execute_after_query(qry, _exec_action)
         else:
-            action()
+            _exec_action()
         return self
 
     def clone_object(self):
@@ -184,3 +184,16 @@ class ClientObject(object):
     @property
     def parent_collection(self):
         return self._parent_collection
+
+    def to_json(self, json_format=None):
+        """
+        :type json_format: office365.runtime.odata.odata_json_format.ODataJsonFormat or None
+        """
+        json = dict((k, self.get_property(k)) for k in self.properties if k in self._changed_properties)
+        for k, v in json.items():
+            if isinstance(v, ClientObject) or isinstance(v, ClientValue):
+                json[k] = v.to_json(json_format)
+
+        if isinstance(json_format, JsonLightFormat) and json_format.is_verbose and self.entity_type_name is not None:
+            json[json_format.metadata_type_tag_name] = {'type': self.entity_type_name}
+        return json
