@@ -1,6 +1,6 @@
 import json
 import re
-from email import message_from_bytes
+from office365.runtime.compat import message_from_bytes_or_string, message_as_bytes_or_string
 from email.message import Message
 
 from office365.runtime.client_request import ClientRequest
@@ -14,25 +14,30 @@ class ODataBatchRequest(ClientRequest):
     def __init__(self, context):
         super(ODataBatchRequest, self).__init__(context)
 
-    def build_request(self):
+    def build_request(self, query):
+        """
+
+        :type query: office365.runtime.queries.client_query.BatchQuery
+        """
         url = "{0}$batch".format(self.context.service_root_url())
         request = RequestOptions(url)
         request.method = HttpMethod.Post
         media_type = "multipart/mixed"
-        content_type = "; ".join([media_type, "boundary={0}".format(self._current_query.current_boundary)])
+        content_type = "; ".join([media_type, "boundary={0}".format(query.current_boundary)])
         request.ensure_header('Content-Type', content_type)
-        request.data = self._prepare_payload().as_bytes()
+        request.data = self._prepare_payload(query)
         return request
 
-    def process_response(self, response):
+    def process_response(self, response, query):
         """Parses an HTTP response.
 
         :type response: requests.Response
+        :type query: office365.runtime.queries.client_query.BatchQuery
         """
         content_id = 0
         for response_info in self._read_response(response):
             if response_info["content"] is not None:
-                qry = self._current_query.get(content_id)
+                qry = query.get(content_id)
                 self.context.pending_request().map_json(response_info["content"], qry.return_type)
                 content_id += 1
 
@@ -49,35 +54,38 @@ class ODataBatchRequest(ClientRequest):
             + response.content
         )
 
-        message = message_from_bytes(http_body)  # type: Message
+        message = message_from_bytes_or_string(http_body)  # type: Message
         for raw_response in message.get_payload():
             if raw_response.get_content_type() == "application/http":
                 yield self._deserialize_response(raw_response)
 
-    def _prepare_payload(self):
-        """Serializes a batch request body."""
+    def _prepare_payload(self, query):
+        """Serializes a batch request body.
+
+        :type query BatchQuery
+        """
         main_message = Message()
         main_message.add_header("Content-Type", "multipart/mixed")
-        main_message.set_boundary(self._current_query.current_boundary)
+        main_message.set_boundary(query.current_boundary)
 
-        if self._current_query.has_change_sets:
+        if query.has_change_sets:
             change_set_message = Message()
             change_set_boundary = create_boundary("changeset_", True)
             change_set_message.add_header("Content-Type", "multipart/mixed")
             change_set_message.set_boundary(change_set_boundary)
 
-            for qry in self._current_query.change_sets:
+            for qry in query.change_sets:
                 request = qry.build_request()
                 message = self._serialize_request(request)
                 change_set_message.attach(message)
             main_message.attach(change_set_message)
 
-        for qry in self._current_query.get_queries:
+        for qry in query.get_queries:
             request = qry.build_request()
             message = self._serialize_request(request)
             main_message.attach(message)
 
-        return main_message
+        return message_as_bytes_or_string(main_message)
 
     @staticmethod
     def _normalize_headers(headers_raw):
@@ -106,7 +114,8 @@ class ODataBatchRequest(ClientRequest):
                 "content": None
             }
         else:
-            *headers_raw, content = lines[1:]
+            headers_raw = lines[1:-1]
+            content = lines[-1]
             content = json.loads(content)
             return {
                 "status": status_info,
@@ -125,23 +134,16 @@ class ODataBatchRequest(ClientRequest):
         method = request.method
         if "X-HTTP-Method" in request.headers:
             method = request.headers["X-HTTP-Method"]
-        lines = ["{method} {url} HTTP/1.1".format(method=method, url=request.url),
-                 *[':'.join(h) for h in request.headers.items()]]
+        lines = ["{method} {url} HTTP/1.1".format(method=method, url=request.url)] + \
+                [':'.join(h) for h in request.headers.items()]
         if request.data:
             lines.append(eol)
             lines.append(json.dumps(request.data))
-        buffer = eol + eol.join(lines) + eol
-        payload = buffer.encode('utf-8').lstrip()
+        raw_content = eol + eol.join(lines) + eol
+        payload = raw_content.encode('utf-8').lstrip()
 
         message = Message()
         message.add_header("Content-Type", "application/http")
         message.add_header("Content-Transfer-Encoding", "binary")
         message.set_payload(payload)
         return message
-
-    def next_query(self):
-        queries = [qry for qry in self.context.pending_request().next_query()]
-        if len(queries) > 0:
-            batch_qry = BatchQuery(self.context, queries)  # Aggregate requests into batch request
-            self._current_query = batch_qry
-            yield batch_qry
