@@ -30,7 +30,8 @@ class ServiceOperationQuery(ClientQuery):
             url = self.context.service_root_url() + \
                   '.'.join([self.binding_type.entity_type_name, method_path.to_url()])
         else:
-            url = '/'.join([self.binding_type.resource_url, method_path.to_url()])
+            delimiter = self.binding_type.resource_path.delimiter
+            url = delimiter.join([self.binding_type.resource_url, method_path.to_url()])
         return url
 
     @property
