@@ -1,12 +1,11 @@
-
 class ResourcePath(object):
     """OData resource path"""
 
     def __init__(self, segment, parent=None):
         """
 
-        :type parent: ResourcePath
         :type segment: str
+        :type parent: ResourcePath or None
         """
         self._segment = segment
         self._parent = parent
@@ -16,13 +15,17 @@ class ResourcePath(object):
         Builds url
         :rtype: str
         """
-        delimiter = '/'
         current = self
         segments = []
         while current:
             segments.insert(0, current.segment)
+            if current.parent:
+                if current.parent.delimiter_precedence > current.delimiter_precedence:
+                    segments.insert(0, current.parent.delimiter)
+                else:
+                    segments.insert(0, current.delimiter)
             current = current.parent
-        return delimiter.join(segments)
+        return "".join(segments)
 
     @property
     def parent(self):
@@ -32,3 +35,10 @@ class ResourcePath(object):
     def segment(self):
         return self._segment
 
+    @property
+    def delimiter(self):
+        return "/"
+
+    @property
+    def delimiter_precedence(self):
+        return 1
