@@ -428,7 +428,4 @@ class List(SecurableObject):
             if name == "Id":
                 self._resource_path = ResourcePathServiceOperation(
                     "GetById", [value], self._parent_collection.resource_path)
-            elif name == "Title":
-                self._resource_path = ResourcePathServiceOperation(
-                    "GetByTitle", [value], self._parent_collection.resource_path)
         return self
