@@ -5,13 +5,13 @@ from office365.runtime.client_value_collection import ClientValueCollection
 class TaxonomyFieldValue(ClientValue):
 
     def __init__(self, label=None, term_guid=None, wss_id=-1):
-        super().__init__()
+        super(TaxonomyFieldValue, self).__init__()
         self.Label = label
         self.TermGuid = term_guid
         self.WssId = wss_id
 
     def __str__(self):
-        return f"{self.WssId};#{self.Label}|{self.TermGuid}"
+        return "{0};#{1}|{2}".format(self.WssId, self.Label, self.TermGuid)
 
     @property
     def entity_type_name(self):
@@ -22,7 +22,7 @@ class TaxonomyFieldValueCollection(ClientValueCollection):
     """Represents the multi-value object for the taxonomy column."""
 
     def __init__(self, initial_values):
-        super().__init__(TaxonomyFieldValue, initial_values)
+        super(TaxonomyFieldValueCollection, self).__init__(TaxonomyFieldValue, initial_values)
 
     def __str__(self):
         return ";#".join([str(item) for item in self._data])
