@@ -12,10 +12,10 @@ class TaxonomyService(ClientRuntimeContext):
         """
         :type  context: office365.sharepoint.client_context.ClientContext
         """
-        super().__init__()
+        super(TaxonomyService, self).__init__()
         self._auth_context = context.authentication_context
         self._pendingRequest = ODataRequest(self, V4JsonFormat("minimal"))
-        self._service_root_url = f"{context.service_root_url()}v2.1/"
+        self._service_root_url = "{0}v2.1/".format(context.service_root_url())
 
     def authenticate_request(self, request):
         self._auth_context.authenticate_request(request)
