@@ -1,10 +1,11 @@
+# coding=utf-8
 from office365.runtime.client_result import ClientResult
 from office365.runtime.client_value_collection import ClientValueCollection
 from office365.runtime.queries.client_query import ClientQuery
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 from office365.runtime.resource_path import ResourcePath
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
-from office365.sharepoint.actions.getWebUrlFromPage import GetWebUrlFromPageUrlQuery
+from office365.sharepoint.actions.getWebUrlFromPage import create_get_web_url_from_page_url_query
 from office365.sharepoint.alerts.alert_collection import AlertCollection
 from office365.sharepoint.changes.change_collection import ChangeCollection
 from office365.sharepoint.clientsidecomponent.types import SPClientSideComponentQueryResult
@@ -41,6 +42,7 @@ from office365.sharepoint.webparts.client_web_part_collection import ClientWebPa
 from office365.sharepoint.webs.regional_settings import RegionalSettings
 from office365.sharepoint.webs.web_information_collection import WebInformationCollection
 from office365.sharepoint.webs.web_template_collection import WebTemplateCollection
+from office365.sharepoint.types.resource_path import ResourcePath as SPResPath
 
 
 class Web(SecurableObject):
@@ -80,7 +82,7 @@ class Web(SecurableObject):
         :type context: office365.sharepoint.client_context.ClientContext
         :type page_full_url: str
         """
-        qry = GetWebUrlFromPageUrlQuery(context, page_full_url)
+        qry = create_get_web_url_from_page_url_query(context, page_full_url)
         context.add_query(qry)
         return qry.return_type
 
@@ -849,6 +851,13 @@ class Web(SecurableObject):
         """
         return self.properties.get('UIVersion', None)
 
+    @property
+    def server_relative_path(self):
+        """Gets the server-relative Path of the Web.
+        :rtype: SPResPath or None
+        """
+        return self.properties.get("ServerRelativePath", SPResPath(None))
+
     def get_property(self, name):
         if name == "ContentTypes":
             return self.content_types
