@@ -1,9 +1,9 @@
-from office365.runtime.client_object_collection import ClientObjectCollection
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.sharepoint.base_entity_collection import BaseEntityCollection
 from office365.sharepoint.webs.web import Web
 
 
-class WebCollection(ClientObjectCollection):
+class WebCollection(BaseEntityCollection):
     """Web collection"""
 
     def __init__(self, context, resource_path=None, parent_web_url=None):
@@ -11,6 +11,11 @@ class WebCollection(ClientObjectCollection):
         self._parent_web_url = parent_web_url
 
     def add(self, web_creation_information):
+        """
+        Create web site
+
+        :type web_creation_information: office365.sharepoint.webs.web_creation_information.WebCreationInformation
+        """
         target_web = Web(self.context)
         self.add_child(target_web)
         qry = ServiceOperationQuery(self, "add", None, web_creation_information, "parameters", target_web)
