@@ -34,8 +34,9 @@ class TeamCollection(EntityCollection):
         def _process_response(resp):
             for grp in groups:
                 if "Team" in grp.properties["resourceProvisioningOptions"]:
-                    new_team = Team(self.context, ResourcePath(grp.properties["id"], self.resource_path),
-                                    grp.properties)
+                    new_team = Team(self.context, ResourcePath(grp.properties["id"], self.resource_path))
+                    for k, v in grp.properties.items():
+                        new_team.set_property(k, v)
                     self.add_child(new_team)
         self.context.after_execute(_process_response)
         return self
