@@ -1,8 +1,8 @@
-from office365.runtime.client_object_collection import ClientObjectCollection
+from office365.entity_collection import EntityCollection
 from office365.teams.teamsAsyncOperation import TeamsAsyncOperation
 
 
-class TeamsAsyncOperationCollection(ClientObjectCollection):
+class TeamsAsyncOperationCollection(EntityCollection):
     """TeamsAsyncOperation's collection"""
 
     def __init__(self, context, resource_path=None):
