@@ -1,3 +1,4 @@
+from office365.runtime.client_value_collection import ClientValueCollection
 from tests import create_unique_name, test_tenant
 from tests.graph_case import GraphTestCase
 
@@ -24,7 +25,18 @@ class TestGraphUser(GraphTestCase):
         self.assertIsNotNone(new_user.id)
         self.__class__.test_user = new_user
 
-    def test3_update_user(self):
+    def test3_get_user_properties(self):
+        user = self.__class__.test_user.select(["assignedLicenses"]).get().execute_query()
+        self.assertIsInstance(user.assigned_licenses, ClientValueCollection)
+
+    def test4_user_add_license(self):
+        skus = self.client.subscribed_skus.get().execute_query()
+        self.assertIsNotNone(skus.resource_path)
+
+    def test5_user_remove_license(self):
+        pass
+
+    def test6_update_user(self):
         user_to_update = self.__class__.test_user
         prop_name = 'city'
         prop_val = create_unique_name("city_")
@@ -33,6 +45,6 @@ class TestGraphUser(GraphTestCase):
         result = self.client.users.filter("{0} eq '{1}'".format(prop_name, prop_val)).get().execute_query()
         self.assertEqual(1, len(result))
 
-    def test4_delete_user(self):
+    def test7_delete_user(self):
         user_to_delete = self.__class__.test_user
         user_to_delete.delete_object(True).execute_query()
