@@ -30,19 +30,16 @@ class TestSPPublishing(SPTestCase):
         self.assertEqual(time_zone.properties.get("Location"), "Moscow, Russia")
 
     def test4_compute_file_name(self):
-        result = SitePageService.compute_file_name(self.client, "Test page")
-        self.client.execute_query()
+        result = SitePageService.compute_file_name(self.client, "Test page").execute_query()
         self.assertIsNotNone(result.value)
 
     def test5_file_picker_tab_options(self):
-        result = SitePageService.file_picker_tab_options(self.client)
-        self.client.execute_query()
-        self.assertIsNotNone(result)
+        result = SitePageService.file_picker_tab_options(self.client).execute_query()
+        self.assertIsNotNone(result.value)
 
     def test6_org_assets(self):
-        result = SitePageService.org_assets(self.client)
-        self.client.execute_query()
-        self.assertIsNotNone(result)
+        result = SitePageService.org_assets(self.client).execute_query()
+        self.assertIsNotNone(result.value)
 
     def test7_get_video_service_manager(self):
         discoverer = VideoServiceDiscoverer(self.client).get().execute_query()
